@@ -1,5 +1,6 @@
 import os
 import cairo
+import time
 
 class BuildPluginsList():
 
@@ -13,10 +14,12 @@ class BuildPluginsList():
     def __init__(self, osmMapa, config):
         self.plugins = []
         self.CONFIG = config
-
-        for dirname, dirnames, filenames in os.walk( "./plugins/", topdown=True):
+        plug_time = []
+        tTotal = 0
+        for dirname, dirnames, filenames in os.walk( "./plugins/"):
             for filename in filenames:
                 if dirname == "./plugins/" and filename<>"plugin_proto.py" and filename.find(".pyo") == -1 and filename.find(".png") == -1 and filename.find(".txt") == -1 and filename.find("dont_") == -1 and filename.find("/") == -1:
+                    t = time.time()
                     name = filename.replace(".py", "")
                     path = "plugins.%s" % name
                     plug_name = "plugins/%s"%name
@@ -40,7 +43,13 @@ class BuildPluginsList():
 
 
                     self.plugins.append([c,plugin_name, ico])
-
+                    add_time = "%f sec\t\t %s\t[%s]" % ( (time.time()-t),filename, plug_name )
+                    tTotal+= (time.time()-t)
+                    plug_time.append( add_time )
+        plug_time.sort()
+        for p in plug_time:
+            print "- ",p
+        print "total init time: ",tTotal
 
     def get_plugins_list(self):
         return self.plugins
\ No newline at end of file
