@@ -15,10 +15,11 @@ import thread
 from threading import Thread
 
 from decode_line import *
+from h_UI_helper import *
+from math_helper import *
 
 
-
-class MyZoomSelect(gtk.Dialog):
+class MyZoomSelect(gtk.Dialog, h_UI_helper):
 
     def act_download(self,widget):
         self.p.zoom_min = int(self.h_min.get_value())
@@ -42,10 +43,7 @@ class MyZoomSelect(gtk.Dialog):
         self.h_max.set_value(16)
         self.vbox.pack_start( self.h_max, True,True,0)
 
-        bt_download = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Download")
-        bt_download.connect("clicked", self.act_download)
-        self.vbox.pack_start( bt_download, True, True, 0)
+        self.vbox.pack_start( self.bt("Download", self.act_download), True, True, 0)
 
         self.show_all()
 
@@ -326,7 +324,7 @@ class SaveTrackDialog( hildon.Program):
         return tr
 
 
-class google_routesearch:
+class google_routesearch(h_UI_helper, math_helper):
 
     def __init__(self,osmMapa,CONFIG):
         self.CONFIG = CONFIG
@@ -446,32 +444,9 @@ class google_routesearch:
 
 
     def espeak_cmd(self, str):
-
         print "---- google_routesearch espeak ----"
         print "---- speak [%s] ----" % str
-
-        """
-        if str.find( " onto " ) <> -1:
-            tmp = []
-            tmp = str.split("onto")
-            cmd = "espeak \"%s onto\" && espeak -v %s \"%s\" &" %( tmp[0],self.CONFIG['google_routesearch_speak_street_lang'], tmp[1])
-        elif str.find( " toward " ) <> -1:
-            tmp = []
-            tmp = str.split("toward")
-            cmd = "espeak \"%s toward\" && espeak -v %s \"%s\" &" %( tmp[0],self.CONFIG['google_routesearch_speak_street_lang'], tmp[1])
-        elif str.find( " to stay on " ) <> -1:
-            tmp = []
-            tmp = str.split(" to stay on ")
-            cmd = "espeak \"%s to stay on\" && espeak -v %s \"%s\" &" %( tmp[0],self.CONFIG['google_routesearch_speak_street_lang'], tmp[1])
-        else:
-             cmd = "espeak \"%s\""%( str)
-        """
         cmd = "espeak -v %s \"%s\" &"%( self.CONFIG['google_routesearch_speak_street_lang'], str)
-
-
-
-
-
         #print "[[[%s]]]"%cmd
         #return None
         os.system(cmd)
@@ -482,34 +457,7 @@ class google_routesearch:
     def get_name(self):
         return "Google - routesearch"
 
-    def dist_from_vector(self, pa,pb,pc):
-        tr = 0.0
-
-        a = (pb[1]-pa[1])/(pb[0]-pa[0])
-        c = pa[1]-( pa[0]*( a  ) )
-        b = (((-a)*pa[0])-c)/pa[1]
-
-        d = a*pc[0]+b*pc[1]+c
-        if d < 0:
-            d = -d
-        tr = d/( math.sqrt( (a*a)+(b*b) ) )
-
-        return tr
-
-    def angle_from_vector(self, pa, pb, pc):
-        a0 = self.osmMapa.cal_angle(pc[0],pc[1], pb[0],pb[1]  )
-        a1 = self.osmMapa.cal_angle(pa[0],pa[1], pb[0],pb[1]  )
-        res = a0[0]-a1[0]
-        if res == 0.0:
-            return 10.0
-
-        if res < 0:
-            res = -res
-        res -= 3.14159265
-        if res < 0:
-            res = -res
-        return res
-
+    
     def get_key_point_speak(self,m ):
         if not self.CONFIG['google_routesearch_speak_streets_names']:
             return m[5]
@@ -517,9 +465,11 @@ class google_routesearch:
             return m[2]
 
     def do_draw(self, gpsmap, gdkdrawable):
-        if notself.drive_mode:
+        if not self.drive_mode:
             return 0
         
+        #self.osmMapa.marker_draw_redraw_made = 0
+        
         print "drive mode", self.drive_mode
 
         if self.osmMapa.osm.props.zoom>self.zoom_minimum:
@@ -824,6 +774,7 @@ class google_routesearch:
         else:
             self.e_end.set_text( "loc:%f+%f"%(self.osmMapa.osm.props.latitude, self.osmMapa.osm.props.longitude) )
             self.CONFIG['google_routesearch_to'] = self.e_end.get_text()
+            
     def on_changed_mode (self,picker):
         str = picker.get_value()
         id = -1
@@ -836,6 +787,7 @@ class google_routesearch:
                 iter+=1
         print "selected mode: ", self.mode[id]
         self.CONFIG['google_routesearch_mode'] = id
+        
     def on_changed_lang (self,picker,dialog):
         str = picker.get_value()
         for i, lang_name in enumerate(self.espeak_langs):
@@ -894,8 +846,10 @@ class google_routesearch:
 </trk>
 </gpx>"""         )
             f.close()
+            
     def on_bt_speak(self, w):
         self.CONFIG['google_routesearch_speak'] = w.get_active()
+        
     def on_bt_speak_st(self, w):
         self.CONFIG['google_routesearch_speak_streets_names'] = w.get_active()
 
@@ -930,16 +884,8 @@ class google_routesearch:
 
 
         scbox = gtk.HBox()
-        bt_swap = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL, "swap")
-        #bt_swap.set_text("swap points","some value")
-        bt_swap.connect("clicked", self.on_swap)
-        scbox.pack_start( bt_swap, False)
-
-        bt_c = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Clear")
-        bt_c.connect("clicked", self.on_clean)
-        scbox.pack_start( bt_c, False)
+        scbox.pack_start( self.bt("swap",self.on_swap), False)
+        scbox.pack_start( self.bt("Clear", self.on_clean), False)
 
 
 
@@ -951,37 +897,13 @@ class google_routesearch:
 
 
 
-
-
-
-
-        """
-        #sftp://yoyo@yoyo.ghost.pl/home/yoyo/yosmapa_builder/yosmapa_builder
-        self.bt_auto = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
-        self.bt_auto.set_label("auto")
-        hbox.pack_start(self.bt_offline, True)
-        mvbox.pack_start( hbox, True )
-        """
-
         hbox = gtk.HBox()
 
-        bt_a = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add")
-        bt_a.connect("clicked", self.on_add)
-        hbox.pack_start( bt_a, False)
-
-
-        bt_search = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Find route")
-        bt_search.connect("clicked", self.on_search, dialog)
-        hbox.pack_start( bt_search, True)
+        hbox.pack_start( self.bt("Add",self.on_add), False)
+        hbox.pack_start( self.bt("Find route", self.on_search, dialog), True)
 
         if len( self.tracks ):
-            bt_clear = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Clear route")
-            bt_clear.connect("clicked", self.on_clear, dialog)
-            hbox.pack_start( bt_clear, True)
-
+            hbox.pack_start( self.bt("Clear route", self.on_clear, dialog), True)
 
         mvbox.pack_start(hbox, True)
 
@@ -1051,10 +973,7 @@ class google_routesearch:
             mvbox.pack_start(gtk.HSeparator(),True)
 
         if len( self.tracks ):
-            bt_export = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Export route to gpx")
-            bt_export.connect("clicked", self.on_bt_export, dialog )
-            mvbox.pack_start( bt_export, True)
+            mvbox.pack_start( self.bt("Export route to gpx", self.on_bt_export, dialog), True)
             mvbox.pack_start(gtk.HSeparator(),True)
 
 
